#!/usr/bin/env  python3

from typing import List
from subprocess import Popen

class Job:
    """
    Circleci job
    """
    def __init__(self, name: str, workflow: str, circleci_config: str, requires: List[str] = None):
        self.name = name
        self.workflow = workflow
        self.requires = requires
        self.circleci_config = circleci_config
        self.executed = False
        self.failed = False
        self.process = None

    def run(self, circleci_cli: str= "/usr/local/bin/circleci"):
        self.process = Popen([circleci_cli, 'local', 'execute', '-c', self.circleci_config, '--job', self.name])
        self.process.wait()
        if self.process.returncode == 0:
            self.executed = True
            self.failed = False
        else:
            self.executed = self.failed = True

    
    def __eq__(self, job):
        if self.name == job.name and \
            self.workflow == job.workflow and \
            self.requires == job.requires:
            return True
        return False  
